@@ -67,17 +67,17 @@ class JSONEncoder(json.JSONEncoder):
         return super().default(o)
 
 
-def load(fp: IO, *, cls: Type[json.JSONDecoder] = None, **kwargs) -> None:
+def load(fp: IO, *, cls: Type[json.JSONDecoder] = None, **kwargs):
     return json.load(fp, cls=cls, **kwargs)
 
 
-def loads(data: Union[str, bytes], *, cls: Type[json.JSONDecoder] = None, **kwargs) -> Any:
+def loads(data: Union[str, bytes], *, cls: Type[json.JSONDecoder] = None, **kwargs):
     return json.loads(data, cls=cls, **kwargs)
 
 
-def dump(obj: Any, fp: IO, *, ensure_ascii: bool = False, cls: Type[json.JSONEncoder] = None, indent: int = None, **kwargs) -> None:
+def dump(obj: Any, fp: IO, *, ensure_ascii: bool = False, cls: Type[json.JSONEncoder] = None, indent: int = None, **kwargs):
     return json.dump(obj, fp, ensure_ascii=ensure_ascii, cls=cls or JSONEncoder, indent=indent, **kwargs)
 
 
-def dumps(obj: Any, *, ensure_ascii: bool = False, cls: Type[json.JSONEncoder] = None, indent: int = None, **kwargs) -> str:
+def dumps(obj: Any, *, ensure_ascii: bool = False, cls: Type[json.JSONEncoder] = None, indent: int = None, **kwargs):
     return json.dumps(obj, ensure_ascii=ensure_ascii, cls=cls or JSONEncoder, indent=indent, **kwargs)
